<?php

/*************************************************************************** *  
 * Copyright : geek Software GmbH
 * Internet	 : www.pdf24.org
 *
 * You are not allowed to change this file!
 ***************************************************************************/
 
class PDF24Request {
	var $header;
	var $data;
	var $boundary;
	var $crlf;
	
	function PDF24Request() {	
		$this->header	= "";
		$this->data		= "";
		$this->boundary	= "----pdf24-AaB03x5";
		$this->crlf		= "\r\n";		
	}
	function addHeader($key, $val) {
		$this->header[$key] = $val;
	}
	function addField($name, $data) {		
		$this->data[$name] = $data;		
	}	
	function create() {		
		$header = '';
		$data 	= '';		
		
		$fields = count($this->data);
		foreach($this->data as $name=>$val) {
			$data .= '--' . $this->boundary . $this->crlf;			
			$data .= 'Content-Disposition: form-data; name="' . $name . '"' . $this->crlf . $this->crlf;			
			$data .= $val . $this->crlf;
		}		
		if($fields > 0) {
			$data .= '--' . $this->boundary . '--';
		}
		
		$this->addHeader('Content-Length', strlen($data));
		$this->addHeader('Connection', 'close');
		$this->addHeader('Content-Type', 'multipart/form-data, boundary=' . $this->boundary);		
		foreach($this->header as $key=>$val) {
			$header .= $key . ': ' . $val . $this->crlf;
		}
		$header .= $this->crlf;		
		return $header . $data;
	}
}

class PDF24Response {
	var $header;
	var $body;
	
	function PDF24Response($fp) {
		$this->header = '';
		$this->body = '';
		while(!feof($fp)) {
			$line = fgets($fp, 1024);
			if(trim($line) == '') {
				break;
			}
			$this->header .= $line;
		}
		while(!feof($fp)) {
			$line = fgets($fp, 1024);
			$this->body .= $line;
		}
	}
	function getHeader() {
		return $this->header;
	}
	function getBody() {
		return $this->body;
	}
	function __toString() {
		return $this->header . "\r\n" . $this->body;
	}
}

class PDF24Element {
	var $params;
	function PDF24Element($params = null) {
		$this->params = $params;
		if(!is_array($params)) {
			$this->params = array();
		}
	}
	function setParam($k,$v) {
		$this->params[$k] = $v;
	}
	function setParams($params) {
		$this->params = $params;
	}
	function addParams($params) {
		$this->params = array_merge($this->params, $params);
	}
	function getParam($k) {
		return $this->params[$k];
	}
	function setTitle($title) {
		$this->setParam('title',$title);
	}
	function setUrl($url) {
		$this->setParam('url',$url);
	}
	function setAuthor($author) {
		$this->setParam('author',$author);
	}
	function setDateTime($dateTime) {
		$this->setParam('dateTime',$dateTime);
	}
	function setBody($body) {
		$this->setParam('body',$body);
	}
}

class PDF24Doc {
	var $params;
	var $elements;
	var $response;
	
	function PDF24Doc($params = null) {
		if(is_array($params)) {
			$this->params = $params;
		} else {
			$this->params = array();
		}
		$this->elements = array();
	}
	function setParam($k, $v) {
		$this->params[$k] = $v;
	}
	function setParams($params) {
		$this->params = $params;
	}
	function addParams($params) {
		$this->params = array_merge($this->params, $params);
	}
	function getParam($k) {
		return $this->params[$k];
	}
	function setEmailTo($to) {
		$this->setParam('emailTo', trim($to));
	}
	function addEmailTo($to) {
		if(isset($this->params['emailTo'])) {
			$this->params['emailTo'] = $this->params['emailTo'] . ';' . trim($to);
		} else {
			$this->setParam('emailTo', trim($to));
		}
	}	
	function setEmailFrom($from) {
		$this->setParam('emailFrom', $from);
	}
	function setEmailSubject($subject) {
		$this->setParam('emailSubject', $subject);
	}
	function setEmailBody($body) {
		$this->setParam('emailBody', $body);
	}
	function setEmailBodyType($type) {
		$this->setParam('emailBodyType', $type);
	}
	function setEmailCharset($charset) {
		$this->setParam('emailCharset', $charset);
	}
	function setHeadlineUrl($url) {
		$this->setParam('headlineUrl', $url);
	}
	function setBaseUrl($baseUrl) {
		$this->setParam('baseUrl', $baseUrl);
	}
	function setHeadline($headline) {
		$this->setParam('headline', $headline);
	}
	function setCharset($charset) {
		$this->setParam('charset', $charset);
	}
	function setPageSize($width, $height) {
		$this->setParam('pageSize', $width . 'x' . $height);
	}
	function setFileName($fileName) {
		$this->setParam('filename', $fileName);
	}
	function addElement($element) {
		if(is_a($element, 'PDF24Element')) {
			$this->addElement($element->params);
		} else if(is_array($element)) {
			$this->elements[] = $element;
		}
	}
	function getResponse() {
		return $this->response;
	}
	function getRequest() {
		$elementCount = count($this->elements);		
		if($elementCount == 0 || !isset($this->params['emailTo'])) {			
			return false;
		}		
		$referer = isset($_SERVER["HTTP_REFERER"]) ? $_SERVER["HTTP_REFERER"] : "";
		$acceptLang = isset($_SERVER["HTTP_ACCEPT_LANGUAGE"]) ? $_SERVER["HTTP_ACCEPT_LANGUAGE"] : "";
	
		$req = new PDF24Request();
		$req->addHeader("User-Agent", "pdf24-API");
		$req->addHeader("Accept-Language", $acceptLang);
		$req->addHeader("Referer", $referer);
		
		$req->addField("elementCount", $elementCount);
		foreach($this->params as $key => $val) {
			$req->addField($key, $val);
		}
		
		for($i = 0; $i < $elementCount; $i++) {
			$element = $this->elements[$i];
			foreach($element as $key => $val) {
				$req->addField('e_' . $key . $i, $val);
			}
		}
		return $req;
	}
	
	//DO NOT CHANGE!!
	var $serviceHost = "doc2pdf.pdf24.org";
	var $servicePort = "80";
	var $servicePath = "/doc2pdf/api1.php";
	
	function createAndSend() {
		$req = $this->getRequest();
		if($req === false) {
			return false;
		}
		$fp = fsockopen ($this->serviceHost, $this->servicePort, $errno, $errstr, 5*60);
		if ($fp === false) {
			return false;
		}
		fputs($fp, 'POST ' . $this->servicePath . " HTTP/1.1\r\n");
		fputs($fp, 'Host: ' . $this->serviceHost . "\r\n");
		fputs($fp, $req->create());
		
		$this->response = new PDF24Response($fp);
		fclose($fp);
		return 	$this->response->getBody() == 'OK';
	}
}

?>
